<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="分类名称" prop="productName">
        <el-input v-model="queryParams.productName" placeholder="请输入分类名称" clearable size="small" @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="父节点" prop="pid">
        <el-select v-model="queryParams.pid" placeholder="请输入父节点" clearable>
          <el-option label="无" value="0"></el-option>
          <el-option v-for="(item, index) in infoListFa" :key="index" :label="item.productName" :value="item.id"></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="分类描述" prop="describe">
        <el-input
          v-model="queryParams.describe"
          placeholder="请输入分类描述，该分类名称的描述"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="cyan" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" icon="el-icon-plus" size="mini" @click="handleAdd" v-hasPermi="['product:info:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="success" icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate" v-hasPermi="['product:info:edit']"
          >修改</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete" v-hasPermi="['product:info:remove']"
          >删除</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" icon="el-icon-download" size="mini" @click="handleExport" v-hasPermi="['product:info:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="infoList" @selection-change="handleSelectionChange" max-height="650">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="主键" align="center" prop="id" />
      <el-table-column label="分类名称" align="center" prop="productName" />
      <el-table-column label="父节点" align="center" prop="pid" />
      <el-table-column label="图标" align="center" width="180">
        <template slot-scope="scope">
          <img :src="scope.row.fileUrl" class="avatar" />
        </template>
      </el-table-column>
      <el-table-column label="分类描述" align="center" prop="describe" />
      <el-table-column label="权重" align="center" prop="weight" />
      <el-table-column label="状态" align="center" prop="status" :formatter="statusFormat"/>
      <el-table-column fixed="right" width="150" label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)" v-hasPermi="['product:info:edit']">修改</el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)" v-hasPermi="['product:info:remove']"
            >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize" @pagination="getList" />

    <!-- 添加或修改品类对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="分类名称" prop="productName">
          <el-input v-model="form.productName" placeholder="请输入分类名称" />
        </el-form-item>
        <el-form-item label="父节点" prop="pid">
          <el-select v-model="form.pid" placeholder="请输入父节点" clearable>
            <el-option label="无" value="0"></el-option>
            <el-option v-for="(item, index) in infoListFa" :key="index" :label="item.productName" :value="item.id"></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="分类图标" prop="describe">
          <el-upload
            class="avatar-uploader"
            :action="`${baseUrl}/open-api/common/file`"
            :show-file-list="false"
            :data="{ fileType: 99 , remark: '品类图标' }"
            name="file"
            :on-success="handleAvatarSuccess"
            drag
          >
            <img v-if="form.fileUrl" :src="form.fileUrl" class="avatar" />
            <i v-else class="el-icon-plus avatar-uploader-icon"></i>
          </el-upload>
        </el-form-item>
        <el-form-item label="分类描述" prop="describe">
          <el-input v-model="form.describe" placeholder="请输入分类描述，该分类名称的描述" />
        </el-form-item>
        <el-form-item label="权重" prop="weight">
          <el-input v-model="form.weight" placeholder="请输入图片名称" />
        </el-form-item>
        <el-form-item label="是否启用" prop="status">
          <el-select v-model="form.status" placeholder="是否启用" clearable>
            <el-option v-for="item in statusOptions" :key="item.dictCode" :label="item.dictLabel" :value="item.dictValue"></el-option>
          </el-select>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listInfo, getInfo, delInfo, addInfo, updateInfo, exportInfo } from '@/api/product/info'

export default {
  name: 'Info',
  data() {
    return {
      baseUrl: process.env.VUE_APP_BASE_API,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 品类表格数据
      infoList: [],
      infoListFa: [],
      // 弹出层标题
      title: '',
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        productName: null,

        pid: null,

        describe: null,

        status: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        productName: [{ required: true, message: '分类名称不能为空', trigger: 'blur' }],

        status: [
          {
            required: true,
            message: '状态  0：有效(默认)、1：失效 不能为空',
            trigger: 'blur'
          }
        ]
      },
      // 小程序状态开关
      statusOptions: [],
      statusFormat: null
    }
  },
  created() {
    this.getList()
    listInfo({
      pid: 0
    }).then(response => {
      this.infoListFa = response.rows
    })
    this.getDicts('wx_open_status').then(response => {
      this.statusOptions = response.data
      this.statusFormat = (row, column) => {
        return this.selectDictLabel(this.statusOptions, row.status)
      }
    })
  },
  methods: {
    //图标上传成功返回函数
    handleAvatarSuccess(response) {
      this.form.productIcon = response.data.fileId
      this.form.fileUrl = response.data.fileUrl
    },
    /** 查询品类列表 */
    getList() {
      this.loading = true
      listInfo(this.queryParams).then(response => {
        this.infoList = response.rows
        this.total = response.total
        this.loading = false
      })
    },
    // 取消按钮
    cancel() {
      this.open = false
      this.reset()
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,

        productName: null,

        pid: null,

        describe: null,

        createTime: null,

        updateTime: null,

        status: 0
      }
      this.resetForm('form')
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1
      this.getList()
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm('queryForm')
      this.handleQuery()
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset()
      this.open = true
      this.title = '添加品类'
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset()
      const id = row.id || this.ids
      getInfo(id).then(response => {
        this.form = response.data
        this.open = true
        this.title = '修改品类'
      })
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs['form'].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateInfo(this.form).then(response => {
              this.msgSuccess('修改成功')
              this.open = false
              this.getList()
            })
          } else {
            addInfo(this.form).then(response => {
              this.msgSuccess('新增成功')
              this.open = false
              this.getList()
            })
          }
        }
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids
      this.$confirm('是否确认删除品类编号为"' + ids + '"的数据项?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(function() {
          return delInfo(ids)
        })
        .then(() => {
          this.getList()
          this.msgSuccess('删除成功')
        })
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams
      this.$confirm('是否确认导出所有品类数据项?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(function() {
          return exportInfo(queryParams)
        })
        .then(response => {
          this.download(response.data)
        })
    }
  }
}
</script>

<style lang="scss" scoped>
.avatar {
  width: 50px;
  height: 50px;
  border: 1px solid #000;
  border-radius: 50%;
}
</style>
